Stan Math Library: stan/math/rev/core/nested_size.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

nested_size.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_CORE_NESTED_SIZE_HPP
2 #define STAN_MATH_REV_CORE_NESTED_SIZE_HPP
3
4 #include <stan/math/rev/core/chainablestack.hpp>
5 #include <cstdlib>
6
7 namespace stan {
8 namespace math {
9
10 static inline size_t nested_size() {
11 return ChainableStack::var_stack_.size()
12 - ChainableStack::nested_var_stack_sizes_.back();
13 }
14
15 }
16 }
17 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::nested_size
static size_t nested_size()
Definition: nested_size.hpp:10
stan::math::AutodiffStackStorage::nested_var_stack_sizes_
static std::vector< size_t > nested_var_stack_sizes_
Definition: autodiffstackstorage.hpp:19
chainablestack.hpp
stan::math::AutodiffStackStorage::var_stack_
static std::vector< ChainableT * > var_stack_
Definition: autodiffstackstorage.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.